==> kubernetes-model-admissionregistration-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SelfSubjectReviewFluent<A extends SelfSubjectReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> withNewMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public SelfSubjectReviewFluent.MetadataNested<A> editMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> editOrNewMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectReviewStatus getStatus();
  public SelfSubjectReviewStatus buildStatus();
  public A withStatus(SelfSubjectReviewStatus status);
  public Boolean hasStatus();
  public SelfSubjectReviewFluent.StatusNested<A> withNewStatus();
  public SelfSubjectReviewFluent.StatusNested<A> withNewStatusLike(SelfSubjectReviewStatus item);
  public SelfSubjectReviewFluent.StatusNested<A> editStatus();
  public SelfSubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public SelfSubjectReviewFluent.StatusNested<A> editOrNewStatusLike(SelfSubjectReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<SelfSubjectReviewFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface StatusNested<N> extends Nested<N>,SelfSubjectReviewStatusFluent<SelfSubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SelfSubjectReviewFluent<A extends SelfSubjectReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> withNewMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public SelfSubjectReviewFluent.MetadataNested<A> editMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> editOrNewMetadata();
  public SelfSubjectReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectReviewStatus getStatus();
  public SelfSubjectReviewStatus buildStatus();
  public A withStatus(SelfSubjectReviewStatus status);
  public Boolean hasStatus();
  public SelfSubjectReviewFluent.StatusNested<A> withNewStatus();
  public SelfSubjectReviewFluent.StatusNested<A> withNewStatusLike(SelfSubjectReviewStatus item);
  public SelfSubjectReviewFluent.StatusNested<A> editStatus();
  public SelfSubjectReviewFluent.StatusNested<A> editOrNewStatus();
  public SelfSubjectReviewFluent.StatusNested<A> editOrNewStatusLike(SelfSubjectReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<SelfSubjectReviewFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface StatusNested<N> extends Nested<N>,SelfSubjectReviewStatusFluent<SelfSubjectReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
